%define version 2023.01

Name:		u-boot
Epoch:		1
Version:	%{version}
Release:	%mkrel 2
Summary:	U-Boot Universal Boot Loader
License:	GPLv2
Group:		System/Kernel and hardware
Url:		https://www.denx.de/wiki/U-Boot
Source0:	https://github.com/u-boot/u-boot/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:		u-boot-2023.01-lmb_max_regions_default_16.patch
Patch1:		u-boot-2023.01-lmb_subset_region_as_equal.patch
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(tinfo)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	bc
# Tools needed for some boards
BuildRequires:	swig
BuildRequires:	pkgconfig(python)
BuildRequires:	dtc
%ifarch aarch64
BuildRequires:	arm-trusted-firmware-armv8
%endif

%define build_boards 0

%ifarch armv5tl armv7hl
%define build_boards 1
%define boards rpi_0_w rpi rpi_2 rpi_3_32b rpi_4_32b Bananapro
%endif
%ifarch aarch64
%define build_boards 1
%define boards rpi_3 rpi_3_b_plus rpi_arm64 rpi_4 pine64_plus
%endif

BuildRequires:  flex bison

%description
Das U-Boot (or just "U-Boot" for short)
is an Open Source Firmware for Embedded PowerPC, ARM, MIPS and x86 processors.

%package tools
Summary:	Tools for the U-Boot Boot Loader
Group:		Development/Other

%description tools
Das U-Boot (or just "U-Boot" for short)
is an Open Source Firmware for Embedded PowerPC, ARM, MIPS and x86 processors.
This package contains:
mkimage a tool that creates kernel bootable images for u-boot.

%package doc
Summary:	Documentation for the U-Boot Boot Loader
Group:		Development/Other
Obsoletes:	u-boot-tools-doc < 20130723-7

%description doc
Das U-Boot (or just "U-Boot" for short) is an Open Source Firmware
for Embedded PowerPC, ARM, MIPS and x86 processors.
This package contains documentation for u-boot firmware

%prep
%setup -q
%autopatch -p1

%build
%if %{build_boards}
for board in %{boards}; do
    if [ $board == "pine64_plus" ]; then
	export BL31=%{_datadir}/arm-trusted-firmware/sun50i_a64/bl31.bin
	export SCP=/dev/null
    else
	unset BL31
    fi
    %make_build O=builds/$board ${board}_defconfig V=1 CONFIG_TOOLS_DEBUG=1
    %make_build O=builds/$board V=1 CONFIG_TOOLS_DEBUG=1
    scripts/get_default_envs.sh ./builds/${board}/ > ./builds/${board}/default_env.txt
done
%endif

make defconfig
%make_build tools-all V=1 CONFIG_TOOLS_DEBUG=1

%install
%if %{build_boards}
for board in %{boards}; do
    install -D -m 0755 builds/$board/{*.bin,default_env.txt} -t %{buildroot}%{_prefix}/lib/%{name}/$board
done
%endif

for tool in asn1_compiler dumpimage env/fw_printenv jtagconsole kwboot netconsole mkenvimage mkimage mksunxiboot sunxi-spl-image-builder; do
	install -D -m 0755 tools/$tool %{buildroot}%{_bindir}/$(basename $tool)
done
ln -s fw_printenv %{buildroot}%{_bindir}/fw_setenv
for man in doc/*.1; do
	install -D -m 0644 $man %{buildroot}%{_mandir}/man1/$(basename $man)
done

%if %{build_boards}
%files
%{_prefix}/lib/%{name}
%endif

%files tools
%{_bindir}/*
%{_mandir}/man1/*.1.*
%doc README

%files doc
%doc doc/README.*


%changelog
* Wed Nov 15 2023 rapsys <rapsys> 1:2023.01-2.mga10
+ Revision: 2006833
- Fix rpi cm4 failed boot with: Reading file would overwrite reserved memory
  Patches referenced in FreeBSD bug report: https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=269181
+ daviddavid <daviddavid>
- use a named-versioned git tarball

* Sat Mar 25 2023 pterjan <pterjan> 1:2023.01-1.mga9
+ Revision: 1950346
- Try to get bl31.bin in the right place for pine64_plus
- arm-trusted-firmware-armv8 is needed on aarch64 to build some boards like pine64_plus
- Add an Epoch as the version is going from 20201007 to 2023.01
- Update to 2023.01

* Sat Mar 26 2022 umeabot <umeabot> 20201007-9.mga9
+ Revision: 1827974
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 20201007-8.mga9
+ Revision: 1747903
- rebuild for openssl 3.0.0

* Tue Feb 02 2021 pterjan <pterjan> 20201007-7.mga8
+ Revision: 1674500
- Drop get_default_envs.sh which doesn't work after install and instead package its output

* Fri Jan 29 2021 pterjan <pterjan> 20201007-6.mga8
+ Revision: 1674013
- Fix fw_setenv symlink

* Fri Jan 29 2021 pterjan <pterjan> 20201007-5.mga8
+ Revision: 1673993
- Fix to not rename fw_printenv to env

* Thu Jan 28 2021 pterjan <pterjan> 20201007-4.mga8
+ Revision: 1673872
- Fix install command
- Add a lot of tools, and extra .bin for boards with several like bananapro

* Mon Dec 21 2020 pterjan <pterjan> 20201007-3.mga8
+ Revision: 1662661
- Replace the patches I found with the simple ones I had written, as they work better
- Add fixes for a crash on RPi4 when a keayboard is present

* Sat Nov 28 2020 pterjan <pterjan> 20201007-2.mga8
+ Revision: 1649936
- Add BuildRequires
- Add BuildRequires
- Drop non building board and add Bananapro
- Build for even more boards
- Build for more boards

* Mon Oct 19 2020 tv <tv> 20201007-1.mga8
+ Revision: 1637133
- BR bison
- 2020.10

* Fri Feb 14 2020 umeabot <umeabot> 20180507-4.mga8
+ Revision: 1517641
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%apply_patches

* Sun Sep 23 2018 umeabot <umeabot> 20180507-3.mga7
+ Revision: 1301486
- Mageia 7 Mass Rebuild

* Wed May 16 2018 blino <blino> 20180507-2.mga7
+ Revision: 1229766
- rebuild because of helloworld.efi parallel build issue

* Wed May 16 2018 blino <blino> 20180507-1.mga7
+ Revision: 1229761
- 2018.05
- drop merged patches

* Wed Apr 04 2018 blino <blino> 20180313-4.mga7
+ Revision: 1215111
- buildrequire bc command (needed for binary_size_check target)

* Fri Mar 30 2018 blino <blino> 20180313-3.mga7
+ Revision: 1213568
- rebuild because of helloworld.efi parallel build issue

* Thu Mar 29 2018 blino <blino> 20180313-2.mga7
+ Revision: 1213554
- Add support for Raspberry Pi 3+ (from Fedora/SUSE)
- Fix issue with certain MMC cards on Raspberry Pi (from Jonathan Gray, through Fedora)

* Thu Mar 29 2018 blino <blino> 20180313-1.mga7
+ Revision: 1213286
- build rpi_0_w board on ARM
- 2018.03

* Sun Feb 11 2018 daviddavid <daviddavid> 20170904-2.mga7
+ Revision: 1200400
- obsoletes old u-boot-tools-doc

* Fri Sep 08 2017 guillomovitch <guillomovitch> 20170904-1.mga7
+ Revision: 1151911
- new version 2017.09
  enforce -g compilation flag usage to produce debug symbols

* Fri May 13 2016 neoclust <neoclust> 20160426-3.mga6
+ Revision: 1014732
- Add rpi on the list of the supported boards
- Add Rpi3_32 on the list of the supported boards
- New version 2016.5 rc3

* Fri May 13 2016 blino <blino> 20160314-2.mga6
+ Revision: 1014475
- build u-boot.bin for Raspberry Pi 2

* Fri May 13 2016 blino <blino> 20160314-1.mga6
+ Revision: 1014444
- update doc files list
- buildrequire openssl-devel for signature feature in tools
- make defconfig before building tools
- rename u-boot-tools source package as u-boot to match upstream name
+ neoclust <neoclust>
- New version 2016.03

* Wed Feb 17 2016 umeabot <umeabot> 20130723-6.mga6
+ Revision: 963144
- Mageia 6 Mass Rebuild

* Fri Oct 23 2015 tv <tv> 20130723-5.mga6
+ Revision: 894639
- do not strip thus fixing debuginfo

* Wed Oct 15 2014 umeabot <umeabot> 20130723-4.mga5
+ Revision: 743543
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 20130723-3.mga5
+ Revision: 690005
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 20130723-2.mga4
+ Revision: 531046
- Mageia 4 Mass Rebuild

* Wed Jul 31 2013 tmb <tmb> 20130723-1.mga4
+ Revision: 461650
- update to 2013.07

* Mon Jan 14 2013 umeabot <umeabot> 20120421-2.mga3
+ Revision: 384937
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Aug 24 2012 fedya <fedya> 20120421-1.mga3
+ Revision: 283641
- is an  open source Firmware
- %%mkrel 1 added
- imported package u-boot-tools

